@@ -1,8 +1,8 @@
 #define QT_FEATURE_ffmpeg 1
 
-#define QT_FEATURE_pipewire -1
+#define QT_FEATURE_pipewire 1
 
-#define QT_FEATURE_pipewire_screencapture -1
+#define QT_FEATURE_pipewire_screencapture 1
 
 #define QT_FEATURE_alsa -1
 
@@ -12,21 +12,21 @@
 
 #define QT_FEATURE_videotoolbox -1
 
-#define QT_FEATURE_gstreamer -1
+#define QT_FEATURE_gstreamer 1
 
-#define QT_FEATURE_gstreamer_photography -1
+#define QT_FEATURE_gstreamer_photography 1
 
-#define QT_FEATURE_gstreamer_gl -1
+#define QT_FEATURE_gstreamer_gl 1
 
-#define QT_FEATURE_gstreamer_gl_wayland -1
+#define QT_FEATURE_gstreamer_gl_wayland 1
 
-#define QT_FEATURE_gstreamer_gl_egl -1
+#define QT_FEATURE_gstreamer_gl_egl 1
 
-#define QT_FEATURE_gstreamer_gl_x11 -1
+#define QT_FEATURE_gstreamer_gl_x11 1
 
 #define QT_FEATURE_gpu_vivante -1
 
-#define QT_FEATURE_linux_v4l -1
+#define QT_FEATURE_linux_v4l 1
 
 #define QT_FEATURE_linux_dmabuf 1
 
@@ -42,6 +42,8 @@
 
 #define QT_FEATURE_wasm -1
 
+#define QT_FEATURE_wasapi -1
+
 #define QT_FEATURE_wmf -1
 
 #define QT_FEATURE_spatialaudio 1
